@@ -39,6 +39,7 @@ const GeocodeFactory = imports.geocode;
 const HeaderBar = imports.headerBar;
 const LocationServiceDialog = imports.locationServiceDialog;
 const MapView = imports.mapView;
+const PlaceBar = imports.placeBar;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
 const PrintOperation = imports.printOperation;
@@ -84,7 +85,8 @@ var MainWindow = GObject.registerClass({
                         'mainGrid',
                         'noNetworkView',
                         'actionBar',
-                        'actionBarRevealer' ]
+                        'actionBarRevealer',
+                        'placeBarContainer' ]
 }, class MainWindow extends Gtk.ApplicationWindow {
 
     get mapView() {
@@ -115,8 +117,9 @@ var MainWindow = GObject.registerClass({
         this._initSignals();
         this._restoreWindowGeometry();
         this._initDND();
+        this._initPlaceBar();
 
-        this._grid.attach(this._sidebar, 1, 0, 1, 1);
+        this._grid.attach(this._sidebar, 1, 0, 1, 2);
 
         this._grid.show_all();
 
@@ -160,6 +163,16 @@ var MainWindow = GObject.registerClass({
         return sidebar;
     }
 
+    _initPlaceBar() {
+        this._placeBar = new PlaceBar.PlaceBar({ mapView: this._mapView,
+                                                 visible: true });
+        this._placeBarContainer.add(this._placeBar);
+
+        this.application.bind_property('selected-place',
+                                       this._placeBar, 'place',
+                                       GObject.BindingFlags.DEFAULT);
+    }
+
     _initDND() {
         this.drag_dest_set(Gtk.DestDefaults.DROP, null, 0);
         this.drag_dest_add_uri_targets();
@@ -179,7 +192,7 @@ var MainWindow = GObject.registerClass({
     }
 
     _initActions() {
-        Utils.addActions(this, {
+        let actions = {
             'about': {
                 onActivate: () => this._onAboutActivate()
             },
@@ -187,14 +200,6 @@ var MainWindow = GObject.registerClass({
                 state: ['b', false],
                 onActivate: () => this._onMapTypeMenuActivate()
             },
-            'switch-to-street-view': {
-                accels: ['<Primary>1', '<Primary>KP_1'],
-                onActivate: () => this._onStreetViewActivate()
-            },
-            'switch-to-aearial-view': {
-                accels: ['<Primary>2', '<Primary>KP_2'],
-                onActivate: () => this._onAerialViewActivate()
-            },
             'hybrid-aerial': {
                 paramType:     'b',
                 setting:       'hybrid-aerial'
@@ -239,7 +244,22 @@ var MainWindow = GObject.registerClass({
             'export-as-image': {
                 onActivate: () => this._onExportActivated()
             }
-        }, Application.settings);
+        };
+
+        // when aerial tiles are available, add shortcuts to switch
+        if (Service.getService().tiles.aerial) {
+            actions['switch-to-street-view'] = {
+                accels: ['<Primary>1', '<Primary>KP_1'],
+                onActivate: () => this._onStreetViewActivate()
+            };
+
+            actions['switch-to-aearial-view'] = {
+                accels: ['<Primary>2', '<Primary>KP_2'],
+                onActivate: () => this._onAerialViewActivate()
+            };
+        }
+
+        Utils.addActions(this, actions, Application.settings);
     }
 
     _initSignals() {
@@ -371,12 +391,14 @@ var MainWindow = GObject.registerClass({
         this.connect('size-allocate', () => {
             let [width, height] = this.get_size();
             if (width < _ADAPTIVE_VIEW_WIDTH) {
+                this.application.adaptive_mode = true;
                 this._headerBarLeft.hide();
                 this._headerBarRight.hide();
                 this._actionBarRevealer.set_reveal_child(true);
                 this._placeEntry.set_margin_start(0);
                 this._placeEntry.set_margin_end(0);
             } else {
+                this.application.adaptive_mode = false;
                 this._headerBarLeft.show();
                 this._headerBarRight.show();
                 this._actionBarRevealer.set_reveal_child(false);
@@ -576,7 +598,7 @@ var MainWindow = GObject.registerClass({
             transient_for: this
         });
 
-        let copyright = _("Copyright © 2011 – 2019 Red Hat, Inc. and The GNOME Maps authors");
+        let copyright = _("Copyright © 2011 – 2021 Red Hat, Inc. and The GNOME Maps authors");
         let attribution = this._getAttribution();
 
         copyright += '\n' + attribution;
