@@ -54,6 +54,7 @@ var SendToDialog = GObject.registerClass({
                         'summaryUrl',
                         'copyButton',
                         'emailButton',
+                        'checkInButton',
                         'scrolledWindow' ]
 }, class SendToDialog extends Gtk.Dialog {
 
@@ -65,6 +66,9 @@ var SendToDialog = GObject.registerClass({
         this._mapView = params.mapView;
         delete params.mapView;
 
+        let showCheckIn = params.showCheckIn || false;
+        delete params.showCheckIn;
+
         params.use_header_bar = true;
         super._init(params);
 
@@ -85,6 +89,19 @@ var SendToDialog = GObject.registerClass({
                 row.set_header(null);
         });
 
+        if (showCheckIn) {
+            Application.checkInManager.bind_property('hasCheckIn',
+                                                     this._checkInButton, 'visible',
+                                                     GObject.BindingFlags.DEFAULT |
+                                                     GObject.BindingFlags.SYNC_CREATE);
+
+            this._checkInButton.connect('clicked', () => {
+                Application.checkInManager.showCheckInDialog(this.get_toplevel(),
+                                                             this._place,
+                                                             false);
+            });
+        }
+
         this.connect('show', () => {
             this._summaryLabel.label = this._getSummary();
             let osmuri = GLib.markup_escape_text(this._getOSMURI(), -1);
@@ -158,8 +175,8 @@ var SendToDialog = GObject.registerClass({
             lines.push(details);
         }
 
-        lines.push('%f, %f'.format(this._location.latitude,
-                                   this._location.longitude));
+        lines.push('%f, %f'.format(this._location.latitude.toFixed(5),
+                                   this._location.longitude.toFixed(5)));
 
         return lines.join('\n');
     }
