@@ -19,6 +19,7 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
+const GLib = imports.gi.GLib;
 const Champlain = imports.gi.Champlain;
 
 const Service = imports.service;
@@ -54,15 +55,36 @@ var TransitRouter = class TransitRoute {
      * of results-
      */
     fetchFirstResults() {
-        let bestProvider = this._getBestProviderForQuery();
+        let pluginOverride = GLib.getenv('TRANSIT_PLUGIN');
 
-        if (bestProvider) {
-            let provider = bestProvider[0];
+        if (pluginOverride) {
+            // override plugin was specified, try instanciating if not done yet
+            if (!this._currPluginInstance) {
+                let module = this._availablePlugins[pluginOverride];
 
-            this._currPluginInstance = bestProvider[1];
-            this._plan.attribution = this._getAttributionForProvider(provider);
-            if (provider.attributionUrl)
-                this._plan.attributionUrl = provider.attributionUrl;
+                if (module) {
+                    this._currPluginInstance =
+                        new imports.transitplugins[module][pluginOverride]();
+                } else {
+                    throw new Error('Specified override plugin not found');
+                }
+            }
+        } else {
+            let bestProvider = this._getBestProviderForQuery();
+
+            this._currPluginInstance = null;
+
+            if (bestProvider) {
+                let provider = bestProvider[0];
+
+                this._currPluginInstance = bestProvider[1];
+                this._plan.attribution = this._getAttributionForProvider(provider);
+                if (provider.attributionUrl)
+                    this._plan.attributionUrl = provider.attributionUrl;
+            }
+        }
+
+        if (this._currPluginInstance) {
             this._currPluginInstance.fetchFirstResults();
         } else {
             this._plan.reset();
@@ -104,8 +126,10 @@ var TransitRouter = class TransitRoute {
             return null;
     }
 
-    _getMatchingProvidersForLocation(location) {
-        let country = Utils.getCountryCodeForCoordinates(location.latitude,
+    _getMatchingProvidersForPlace(place) {
+        let location = place.location;
+        let country = place.country_code ??
+                      Utils.getCountryCodeForCoordinates(location.latitude,
                                                          location.longitude);
 
         let matchingProviders = [];
@@ -169,14 +193,13 @@ var TransitRouter = class TransitRoute {
      *         or null if no matching provider was found.
      */
     _getBestProviderForQuery() {
-        let startLocation = this._query.filledPoints[0].place.location;
-        let endLocation =
-            this._query.filledPoints.last().place.location;
+        let startPlace = this._query.filledPoints[0].place;
+        let endPlace = this._query.filledPoints.last().place;
 
         let matchingProvidersForStart =
-            this._getMatchingProvidersForLocation(startLocation);
+            this._getMatchingProvidersForPlace(startPlace);
         let matchingProvidersForEnd =
-            this._getMatchingProvidersForLocation(endLocation);
+            this._getMatchingProvidersForPlace(endPlace);
 
         let matchingProviders = [];
 
@@ -223,7 +246,7 @@ var TransitRouter = class TransitRoute {
 
                     return [provider, instance];
                 } catch (e) {
-                    Utils.debug('Failed to instanciate transit plugin: ' +
+                    Utils.debug('Failed to instantiate transit plugin: ' +
                                 plugin + ": " + e);
                 }
             } else {
