@@ -36,7 +36,6 @@ const GraphHopperTransit = imports.graphHopperTransit;
 const HTTP = imports.http;
 const HVT = imports.hvt;
 const TransitPlan = imports.transitPlan;
-const TransitTweaks = imports.transitTweaks;
 const Utils = imports.utils;
 
 const BASE_URL = 'https://api.resrobot.se';
@@ -96,7 +95,6 @@ var Resrobot = class Resrobot {
         this._query = Application.routeQuery;
         this._key = params.key;
         this._tz = GLib.TimeZone.new(NATIVE_TIMEZONE);
-        this._tweaks = new TransitTweaks.TransitTweaks({ name: 'resrobot' });
 
         if (!this._key)
             throw new Error('missing key');
@@ -214,9 +212,7 @@ var Resrobot = class Resrobot {
                         // store the back and forward references from the result
                         this._scrB = result.scrB;
                         this._scrF = result.scrF;
-                        this._tweaks.applyTweaks(itineraries, () => {
-                            this._processItineraries(itineraries)
-                        });
+                        this._processItineraries(itineraries);
                     } else {
                         this._noRouteFound();
                     }
@@ -306,7 +302,7 @@ var Resrobot = class Resrobot {
     /* Indicate that no routes where found, either shows the "No route found"
      * message, or in case of loading additional (later/earlier) results,
      * indicate no such where found, so that the sidebar can disable the
-     * "load more" functionallity as appropriate.
+     * "load more" functionality as appropriate.
      */
     _noRouteFound() {
         if (this._extendPrevious) {
@@ -393,7 +389,7 @@ var Resrobot = class Resrobot {
      */
     _canLegBeIgnored(leg) {
         if (!leg.isTransit) {
-            /* check that the distance is below the threashold and also that
+            /* check that the distance is below the threshold and also that
              * the duration is below 1 min, since the API in some occasions
              * apparently gives distance 0, even though a walking leg has
              * longer duration, and spans a distance in coordinates.
